<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
/**
 *
 * @package    block_course_checker
 * @copyright  2019 Liip SA <elearning@liip.ch>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
namespace block_course_checker\model;

defined('MOODLE_INTERNAL') || die();
/**
 * This is an interface made to run a single check.
 */
interface check_plugin_interface{

    /**
     * @param \stdClass $course The course itself.
     * @return check_result_interface The check result.
     */
    public function run($course);

    /**
     * Get the group defined for this check.
     * This is used to display checks from the same group together.
     * @return string
     */
    public static function get_group();

    /**
     * Get the defaultsetting for this check.
     * This is used to set if the checker is enabled/disabled per default in the global settings.
     *
     * @return bool
     */
    public static function is_checker_enabled_by_default();
}